scoretools.GraceContainer
=========================

.. abjad-lineage:: abjad.tools.scoretools.GraceContainer.GraceContainer

.. autoclass:: abjad.tools.scoretools.GraceContainer.GraceContainer

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.scoretools.GraceContainer.GraceContainer.append
      ~abjad.tools.scoretools.GraceContainer.GraceContainer.extend
      ~abjad.tools.scoretools.GraceContainer.GraceContainer.index
      ~abjad.tools.scoretools.GraceContainer.GraceContainer.insert
      ~abjad.tools.scoretools.GraceContainer.GraceContainer.is_simultaneous
      ~abjad.tools.scoretools.GraceContainer.GraceContainer.kind
      ~abjad.tools.scoretools.GraceContainer.GraceContainer.pop
      ~abjad.tools.scoretools.GraceContainer.GraceContainer.remove
      ~abjad.tools.scoretools.GraceContainer.GraceContainer.reverse
      ~abjad.tools.scoretools.GraceContainer.GraceContainer.select_leaves
      ~abjad.tools.scoretools.GraceContainer.GraceContainer.select_notes_and_chords
      ~abjad.tools.scoretools.GraceContainer.GraceContainer.__contains__
      ~abjad.tools.scoretools.GraceContainer.GraceContainer.__copy__
      ~abjad.tools.scoretools.GraceContainer.GraceContainer.__delitem__
      ~abjad.tools.scoretools.GraceContainer.GraceContainer.__eq__
      ~abjad.tools.scoretools.GraceContainer.GraceContainer.__format__
      ~abjad.tools.scoretools.GraceContainer.GraceContainer.__getitem__
      ~abjad.tools.scoretools.GraceContainer.GraceContainer.__illustrate__
      ~abjad.tools.scoretools.GraceContainer.GraceContainer.__len__
      ~abjad.tools.scoretools.GraceContainer.GraceContainer.__mul__
      ~abjad.tools.scoretools.GraceContainer.GraceContainer.__ne__
      ~abjad.tools.scoretools.GraceContainer.GraceContainer.__repr__
      ~abjad.tools.scoretools.GraceContainer.GraceContainer.__rmul__
      ~abjad.tools.scoretools.GraceContainer.GraceContainer.__setitem__

Bases
-----

- :py:class:`scoretools.Container <abjad.tools.scoretools.Container.Container>`

- :py:class:`scoretools.Component <abjad.tools.scoretools.Component.Component>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read/write properties
---------------------

.. autoattribute:: abjad.tools.scoretools.GraceContainer.GraceContainer.is_simultaneous
   :noindex:

.. autoattribute:: abjad.tools.scoretools.GraceContainer.GraceContainer.kind
   :noindex:

Methods
-------

.. automethod:: abjad.tools.scoretools.GraceContainer.GraceContainer.append
   :noindex:

.. automethod:: abjad.tools.scoretools.GraceContainer.GraceContainer.extend
   :noindex:

.. automethod:: abjad.tools.scoretools.GraceContainer.GraceContainer.index
   :noindex:

.. automethod:: abjad.tools.scoretools.GraceContainer.GraceContainer.insert
   :noindex:

.. automethod:: abjad.tools.scoretools.GraceContainer.GraceContainer.pop
   :noindex:

.. automethod:: abjad.tools.scoretools.GraceContainer.GraceContainer.remove
   :noindex:

.. automethod:: abjad.tools.scoretools.GraceContainer.GraceContainer.reverse
   :noindex:

.. automethod:: abjad.tools.scoretools.GraceContainer.GraceContainer.select_leaves
   :noindex:

.. automethod:: abjad.tools.scoretools.GraceContainer.GraceContainer.select_notes_and_chords
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.scoretools.GraceContainer.GraceContainer.__contains__
   :noindex:

.. automethod:: abjad.tools.scoretools.GraceContainer.GraceContainer.__copy__
   :noindex:

.. automethod:: abjad.tools.scoretools.GraceContainer.GraceContainer.__delitem__
   :noindex:

.. automethod:: abjad.tools.scoretools.GraceContainer.GraceContainer.__eq__
   :noindex:

.. automethod:: abjad.tools.scoretools.GraceContainer.GraceContainer.__format__
   :noindex:

.. automethod:: abjad.tools.scoretools.GraceContainer.GraceContainer.__getitem__
   :noindex:

.. automethod:: abjad.tools.scoretools.GraceContainer.GraceContainer.__illustrate__
   :noindex:

.. automethod:: abjad.tools.scoretools.GraceContainer.GraceContainer.__len__
   :noindex:

.. automethod:: abjad.tools.scoretools.GraceContainer.GraceContainer.__mul__
   :noindex:

.. automethod:: abjad.tools.scoretools.GraceContainer.GraceContainer.__ne__
   :noindex:

.. automethod:: abjad.tools.scoretools.GraceContainer.GraceContainer.__repr__
   :noindex:

.. automethod:: abjad.tools.scoretools.GraceContainer.GraceContainer.__rmul__
   :noindex:

.. automethod:: abjad.tools.scoretools.GraceContainer.GraceContainer.__setitem__
   :noindex:
